==> nextcloud-app-contacts-2.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/contacts/l10n/da.js <==
OC.L10N.register(
    "contacts",
    {
    "Contacts" : "Kontakter",
    "Download" : "Download",
    "Copy link" : "Kopier link",
    "Click to copy the link to your clipboard" : "Klik her for at kopiere linket til din udklipsholder",
    "Toggle sharing" : "Toggle deling",
    "Delete" : "Slet",
    "Rename" : "Omdøb",
    "Share with users or groups" : "Del med brugere eller grupper",
    "can edit" : "kan redigere",
    "Close" : "Luk",
    "Copied!" : "Kopieret!",
    "Not supported!" : "Ikke understøttet!",
    "Press ⌘-C to copy." : "Tryk ⌘-C for at kopiere.",
    "Press Ctrl-C to copy." : "Tryk Ctrl-C for at kopiere.",
    "Address book name" : "Adressebogsnavn",
    "Only these special characters are allowed: -_.!?#|()" : "Det er kun tilladt med disse specialtegn: -_.!?#|()",
    "Address book could not be created." : "Adressebog kunne ikke oprettes",
    "The selected image is too big (max 1MB)" : "Det valgte billede er for stort (max 1MB)",
    "This card is corrupted and has been fixed. Please check the data and trigger a save to make the changes permanent." : "Dette kort er beskadiget og er blevet ordnet. Vær venlig at tjekke data og gem for at lave ændringerne permanente.",
    "No contacts in here" : "Ingen kontaktpersoner her",
    "Name" : "Navn",
    "Organization" : "Organisation",
    "Title" : "Titel",
    "Add field …" : "Tilføj felt...",
    "Save changes" : "Gem ændringer",
    "Address book" : "Adressebog",
    "Loading contacts …" : "Henter kontakter …",
    "Import into" : "Importer til",
    "Importing..." : "Importerer...",
    "Select your addressbook" : "Vælg din adressebog",
    "No search result for {query}" : "Ingen søgeresultater for  {query}",
    "All contacts" : "Alle kontakter",
    "Post office box" : "Postboks",
    "Postal code" : "Postnummer",
    "City" : "By",
    "State or province" : "Stat eller provins",
    "Country" : "Land",
    "Address" : "Adresse",
    "(new group)" : "(new group)",
    "Last name" : "Efternavn",
    "First name" : "Fornavn",
    "Additional names" : "Mellemnavne",
    "Prefix" : "Præfiks",
    "Suffix" : "Suffiks",
    "Importing into" : "Importer til",
    "New contact" : "Ny kontakt",
    "Not grouped" : "Ikke i gruppe",
    "Sort by" : "Sortér efter",
    "{addressbook} shared by {owner}" : "{addressbook} delt af {owner}",
    "Contact not found." : "Kontakt blev ikke fundet.",
    "You don't have permission to write to this addressbook." : "Du har ikke tilladelse til at skrive i denne adressebog.",
    "Contact could not be created." : "Kontakt kunne ikke oprettes.",
    "No contacts in file. Only vCard files are allowed." : "Der er ikke fundet nogen kontakter i filen. Kun vCard filer er tilladt.",
    "Only vCard version 4.0 (RFC6350) or version 3.0 (RFC2426) are supported." : "Kun vCard version 4.0 (RFC6350) og version 3.0 (RFC2426) er tilladte.",
    "Contact could not be saved." : "Kontakt kunne ikke gemmes.",
    "Waiting for the server to be ready..." : "Venter på at serveren bliver klar...",
    "Display name" : "Vis navn",
    "Nickname" : "Kaldenavn",
    "Detailed name" : "Detaljeret navn",
    "Notes" : "Noter",
    "Website" : "Hjemmeside",
    "Federated Cloud ID" : "Federated Cloud ID",
    "Home" : "Hjemme",
    "Work" : "Arbejde",
    "Other" : "Andet",
    "Groups" : "Grupper",
    "Birthday" : "Fødselsdag",
    "Anniversary" : "Årsdag",
    "Date of death" : "Dødsdato",
    "Email" : "E-mail",
    "Instant messaging" : "Instant Messaging",
    "Phone" : "Telefon",
    "Mobile" : "Mobil",
    "Fax" : "Fax",
    "Fax home" : "Fax hjemme",
    "Fax work" : "Fax arbejde",
    "Pager" : "Personsøger",
    "Voice" : "Telefonsvarer",
    "Social network" : "Socialt netværk",
    "Relationship" : "Forhold",
    "Spouse" : "Ægtefælle",
    "Child" : "Barn",
    "Mother" : "Mor",
    "Father" : "Far",
    "Parent" : "Forælder",
    "Brother" : "Bror",
    "Sister" : "Søster",
    "Relative" : "Slægtning",
    "Friend" : "Ven",
    "Colleague" : "Kollega",
    "Manager" : "Leder",
    "Assistant" : "Assistent",
    "Gender" : "Køn",
    "Female" : "Kvinde",
    "Male" : "Mand",
    "Details" : "Detaljer",
    "Settings" : "Indstillinger"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-contacts-2.1.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/contacts/l10n/da.js <==
OC.L10N.register(
    "contacts",
    {
    "Contacts" : "Kontakter",
    "Download" : "Download",
    "Copy link" : "Kopier link",
    "Click to copy the link to your clipboard" : "Klik her for at kopiere linket til din udklipsholder",
    "Toggle sharing" : "Toggle deling",
    "Delete" : "Slet",
    "Rename" : "Omdøb",
    "Share with users or groups" : "Del med brugere eller grupper",
    "can edit" : "kan redigere",
    "Close" : "Luk",
    "Copied!" : "Kopieret!",
    "Not supported!" : "Ikke understøttet!",
    "Press ⌘-C to copy." : "Tryk ⌘-C for at kopiere.",
    "Press Ctrl-C to copy." : "Tryk Ctrl-C for at kopiere.",
    "Address book name" : "Adressebogsnavn",
    "Only these special characters are allowed: -_.!?#|()" : "Det er kun tilladt med disse specialtegn: -_.!?#|()",
    "Address book could not be created." : "Adressebog kunne ikke oprettes",
    "The selected image is too big (max 1MB)" : "Det valgte billede er for stort (max 1MB)",
    "This card is corrupted and has been fixed. Please check the data and trigger a save to make the changes permanent." : "Dette kort er beskadiget og er blevet ordnet. Vær venlig at tjekke data og gem for at lave ændringerne permanente.",
    "No contacts in here" : "Ingen kontaktpersoner her",
    "Name" : "Navn",
    "Organization" : "Organisation",
    "Title" : "Titel",
    "Add field …" : "Tilføj felt...",
    "Save changes" : "Gem ændringer",
    "Address book" : "Adressebog",
    "Loading contacts …" : "Henter kontakter …",
    "Import into" : "Importer til",
    "Importing..." : "Importerer...",
    "Select your addressbook" : "Vælg din adressebog",
    "No search result for {query}" : "Ingen søgeresultater for  {query}",
    "All contacts" : "Alle kontakter",
    "Post office box" : "Postboks",
    "Postal code" : "Postnummer",
    "City" : "By",
    "State or province" : "Stat eller provins",
    "Country" : "Land",
    "Address" : "Adresse",
    "(new group)" : "(new group)",
    "Last name" : "Efternavn",
    "First name" : "Fornavn",
    "Additional names" : "Mellemnavne",
    "Prefix" : "Præfiks",
    "Suffix" : "Suffiks",
    "Importing into" : "Importer til",
    "New contact" : "Ny kontakt",
    "Not grouped" : "Ikke i gruppe",
    "Sort by" : "Sortér efter",
    "{addressbook} shared by {owner}" : "{addressbook} delt af {owner}",
    "Contact not found." : "Kontakt blev ikke fundet.",
    "You don't have permission to write to this addressbook." : "Du har ikke tilladelse til at skrive i denne adressebog.",
    "Contact could not be created." : "Kontakt kunne ikke oprettes.",
    "No contacts in file. Only vCard files are allowed." : "Der er ikke fundet nogen kontakter i filen. Kun vCard filer er tilladt.",
    "Only vCard version 4.0 (RFC6350) or version 3.0 (RFC2426) are supported." : "Kun vCard version 4.0 (RFC6350) og version 3.0 (RFC2426) er tilladte.",
    "Contact could not be moved." : "Kontakt kunne ikke flyttes.",
    "Contact could not be saved." : "Kontakt kunne ikke gemmes.",
    "Waiting for the server to be ready…" : "Venter på at serveren bliver klar...",
    "Importing…" : "Importerer...",
    "Display name" : "Vis navn",
    "Nickname" : "Kaldenavn",
    "Detailed name" : "Detaljeret navn",
    "Notes" : "Noter",
    "Website" : "Hjemmeside",
    "Federated Cloud ID" : "Federated Cloud ID",
    "Home" : "Hjemme",
    "Work" : "Arbejde",
    "Other" : "Andet",
    "Groups" : "Grupper",
    "Birthday" : "Fødselsdag",
    "Anniversary" : "Årsdag",
    "Date of death" : "Dødsdato",
    "Email" : "E-mail",
    "Instant messaging" : "Instant Messaging",
    "Phone" : "Telefon",
    "Mobile" : "Mobil",
    "Work mobile" : "Arbdejsmobil",
    "Fax" : "Fax",
    "Fax home" : "Fax hjemme",
    "Fax work" : "Fax arbejde",
    "Pager" : "Personsøger",
    "Voice" : "Telefonsvarer",
    "Car" : "Bil",
    "Work pager" : "Arbejdespager ",
    "Social network" : "Socialt netværk",
    "Relationship" : "Forhold",
    "Spouse" : "Ægtefælle",
    "Child" : "Barn",
    "Mother" : "Mor",
    "Father" : "Far",
    "Parent" : "Forælder",
    "Brother" : "Bror",
    "Sister" : "Søster",
    "Relative" : "Slægtning",
    "Friend" : "Ven",
    "Colleague" : "Kollega",
    "Manager" : "Leder",
    "Assistant" : "Assistent",
    "Gender" : "Køn",
    "Female" : "Kvinde",
    "Male" : "Mand",
    "Details" : "Detaljer",
    "Settings" : "Indstillinger"
},
"nplurals=2; plural=(n != 1);");
